@@ -26,5 +26,12 @@ def get_base_airflow_version_tuple() -> tuple[int, int, int]:
     return airflow_version.major, airflow_version.minor, airflow_version.micro
 
 
-AIRFLOW_V_2_8_PLUS = get_base_airflow_version_tuple() >= (2, 8, 0)
 AIRFLOW_V_3_0_PLUS = get_base_airflow_version_tuple() >= (3, 0, 0)
+
+try:
+    from airflow.sdk.execution_time.timeout import timeout
+except ImportError:
+    from airflow.utils.timeout import timeout  # type: ignore[assignment,attr-defined,no-redef]
+
+
+__all__ = ["AIRFLOW_V_3_0_PLUS", "timeout"]
