@@ -21,6 +21,7 @@ import contextlib
 import importlib
 import json
 import os
+import sys
 from io import StringIO
 from unittest import mock
 from unittest.mock import MagicMock, patch
@@ -36,9 +37,17 @@ from airflow.providers.celery.cli.celery_command import _run_stale_bundle_cleanu
 from tests_common.test_utils.config import conf_vars
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
 
+PY313 = sys.version_info >= (3, 13)
+
+
+@pytest.fixture(autouse=False)
+def conf_stale_bundle_cleanup_disabled():
+    with conf_vars({("dag_processor", "stale_bundle_cleanup_interval"): "0"}):
+        yield
+
 
 @pytest.mark.backend("mysql", "postgres")
-@conf_vars({("dag_processor", "stale_bundle_cleanup_interval"): 0})
+@pytest.mark.usefixtures("conf_stale_bundle_cleanup_disabled")
 class TestCeleryStopCommand:
     @classmethod
     def setup_class(cls):
@@ -120,11 +129,12 @@ class TestCeleryStopCommand:
 
 
 @pytest.mark.backend("mysql", "postgres")
-@conf_vars({("dag_processor", "stale_bundle_cleanup_interval"): 0})
+@pytest.mark.usefixtures("conf_stale_bundle_cleanup_disabled")
 class TestWorkerStart:
     @classmethod
     def setup_class(cls):
         with conf_vars({("core", "executor"): "CeleryExecutor"}):
+            importlib.reload(executor_loader)
             importlib.reload(cli_parser)
             cls.parser = cli_parser.get_parser()
 
@@ -166,10 +176,10 @@ class TestWorkerStart:
                 queues,
                 "--concurrency",
                 int(concurrency),
-                "--hostname",
-                celery_hostname,
                 "--loglevel",
                 conf.get("logging", "CELERY_LOGGING_LEVEL"),
+                "--hostname",
+                celery_hostname,
                 "--autoscale",
                 autoscale,
                 "--without-mingle",
@@ -181,7 +191,7 @@ class TestWorkerStart:
 
 
 @pytest.mark.backend("mysql", "postgres")
-@conf_vars({("dag_processor", "stale_bundle_cleanup_interval"): 0})
+@pytest.mark.usefixtures("conf_stale_bundle_cleanup_disabled")
 class TestWorkerFailure:
     @classmethod
     def setup_class(cls):
@@ -201,7 +211,7 @@ class TestWorkerFailure:
 
 
 @pytest.mark.backend("mysql", "postgres")
-@conf_vars({("dag_processor", "stale_bundle_cleanup_interval"): 0})
+@pytest.mark.usefixtures("conf_stale_bundle_cleanup_disabled")
 class TestFlowerCommand:
     @classmethod
     def setup_class(cls):
@@ -316,16 +326,31 @@ class TestFlowerCommand:
             )
         ]
         mock_pid_file.assert_has_calls([mock.call(mock_setup_locations.return_value[0], -1)])
-        assert mock_open.mock_calls == [
-            mock.call(mock_setup_locations.return_value[1], "a"),
-            mock.call().__enter__(),
-            mock.call(mock_setup_locations.return_value[2], "a"),
-            mock.call().__enter__(),
-            mock.call().truncate(0),
-            mock.call().truncate(0),
-            mock.call().__exit__(None, None, None),
-            mock.call().__exit__(None, None, None),
-        ]
+
+        if PY313:
+            assert mock_open.mock_calls == [
+                mock.call(mock_setup_locations.return_value[1], "a"),
+                mock.call().__enter__(),
+                mock.call(mock_setup_locations.return_value[2], "a"),
+                mock.call().__enter__(),
+                mock.call().truncate(0),
+                mock.call().truncate(0),
+                mock.call().__exit__(None, None, None),
+                mock.call().close(),
+                mock.call().__exit__(None, None, None),
+                mock.call().close(),
+            ]
+        else:
+            assert mock_open.mock_calls == [
+                mock.call(mock_setup_locations.return_value[1], "a"),
+                mock.call().__enter__(),
+                mock.call(mock_setup_locations.return_value[2], "a"),
+                mock.call().__enter__(),
+                mock.call().truncate(0),
+                mock.call().truncate(0),
+                mock.call().__exit__(None, None, None),
+                mock.call().__exit__(None, None, None),
+            ]
 
     @pytest.mark.skipif(AIRFLOW_V_3_0_PLUS, reason="Test requires Airflow 3.0-")
     @mock.patch("airflow.cli.commands.daemon_utils.TimeoutPIDLockFile")
