@@ -34,21 +34,24 @@ from celery.result import AsyncResult
 from kombu.asynchronous import set_event_loop
 
 from airflow.configuration import conf
-from airflow.models.baseoperator import BaseOperator
 from airflow.models.dag import DAG
-from airflow.models.serialized_dag import SerializedDagModel
 from airflow.models.taskinstance import TaskInstance, TaskInstanceKey
 from airflow.providers.celery.executors import celery_executor, celery_executor_utils, default_celery
 from airflow.providers.celery.executors.celery_executor import CeleryExecutor
-from airflow.utils import timezone
 from airflow.utils.state import State
 
 from tests_common.test_utils import db
 from tests_common.test_utils.config import conf_vars
-from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
+from tests_common.test_utils.dag import sync_dag_to_db
+from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS, AIRFLOW_V_3_1_PLUS
 
 if AIRFLOW_V_3_0_PLUS:
     from airflow.models.dag_version import DagVersion
+if AIRFLOW_V_3_1_PLUS:
+    from airflow.sdk import BaseOperator, timezone
+else:
+    from airflow.models.baseoperator import BaseOperator  # type: ignore[attr-defined,no-redef]
+    from airflow.utils import timezone  # type: ignore[attr-defined,no-redef]
 
 pytestmark = pytest.mark.db_test
 
@@ -123,6 +126,24 @@ class TestCeleryExecutor:
     def test_cli_commands_vended(self):
         assert CeleryExecutor.get_cli_commands()
 
+    def test_celery_executor_init_with_args_kwargs(self):
+        """Test that CeleryExecutor properly passes args and kwargs to BaseExecutor."""
+        parallelism = 50
+        team_name = "test_team"
+
+        if AIRFLOW_V_3_1_PLUS:
+            # team_name was added in Airflow 3.1
+            executor = celery_executor.CeleryExecutor(parallelism=parallelism, team_name=team_name)
+        else:
+            executor = celery_executor.CeleryExecutor(parallelism)
+
+        assert executor.parallelism == parallelism
+
+        if AIRFLOW_V_3_1_PLUS:
+            # team_name was added in Airflow 3.1
+            assert executor.team_name == team_name
+            assert executor.conf.team_name == team_name
+
     @pytest.mark.backend("mysql", "postgres")
     def test_exception_propagation(self, caplog):
         caplog.set_level(
@@ -193,15 +214,14 @@ class TestCeleryExecutor:
                 ) or mock_fork.call_args == ((command, "abcdef-124215-abcdef"),)
 
     @pytest.mark.backend("mysql", "postgres")
-    def test_try_adopt_task_instances_none(self):
+    def test_try_adopt_task_instances_none(self, clean_dags_dagruns_and_dagbundles, testing_dag_bundle):
         start_date = timezone.utcnow() - timedelta(days=2)
 
         with DAG("test_try_adopt_task_instances_none", schedule=None) as dag:
             task_1 = BaseOperator(task_id="task_1", start_date=start_date)
 
         if AIRFLOW_V_3_0_PLUS:
-            dag.sync_to_db()
-            SerializedDagModel.write_dag(dag, bundle_name="testing")
+            sync_dag_to_db(dag)
             dag_version = DagVersion.get_latest_version(dag.dag_id)
             key1 = TaskInstance(task=task_1, run_id=None, dag_version_id=dag_version.id)
         else:
@@ -214,7 +234,7 @@ class TestCeleryExecutor:
 
     @pytest.mark.backend("mysql", "postgres")
     @time_machine.travel("2020-01-01", tick=False)
-    def test_try_adopt_task_instances(self):
+    def test_try_adopt_task_instances(self, clean_dags_dagruns_and_dagbundles, testing_dag_bundle):
         start_date = timezone.utcnow() - timedelta(days=2)
 
         with DAG("test_try_adopt_task_instances_none", schedule=None) as dag:
@@ -222,8 +242,7 @@ class TestCeleryExecutor:
             task_2 = BaseOperator(task_id="task_2", start_date=start_date)
 
         if AIRFLOW_V_3_0_PLUS:
-            dag.sync_to_db()
-            SerializedDagModel.write_dag(dag, bundle_name="testing")
+            sync_dag_to_db(dag)
             dag_version = DagVersion.get_latest_version(dag.dag_id)
             ti1 = TaskInstance(task=task_1, run_id=None, dag_version_id=dag_version.id)
             ti2 = TaskInstance(task=task_2, run_id=None, dag_version_id=dag_version.id)
@@ -258,15 +277,16 @@ class TestCeleryExecutor:
 
     @pytest.mark.backend("mysql", "postgres")
     @mock.patch("airflow.providers.celery.executors.celery_executor.CeleryExecutor.fail")
-    def test_cleanup_stuck_queued_tasks(self, mock_fail):
+    def test_cleanup_stuck_queued_tasks(
+        self, mock_fail, clean_dags_dagruns_and_dagbundles, testing_dag_bundle
+    ):
         start_date = timezone.utcnow() - timedelta(days=2)
 
         with DAG("test_cleanup_stuck_queued_tasks_failed", schedule=None) as dag:
             task = BaseOperator(task_id="task_1", start_date=start_date)
 
         if AIRFLOW_V_3_0_PLUS:
-            dag.sync_to_db()
-            SerializedDagModel.write_dag(dag, bundle_name="testing")
+            sync_dag_to_db(dag)
             dag_version = DagVersion.get_latest_version(task.dag.dag_id)
             ti = TaskInstance(task=task, run_id=None, dag_version_id=dag_version.id)
         else:
@@ -293,15 +313,14 @@ class TestCeleryExecutor:
 
     @pytest.mark.backend("mysql", "postgres")
     @mock.patch("airflow.providers.celery.executors.celery_executor.CeleryExecutor.fail")
-    def test_revoke_task(self, mock_fail):
+    def test_revoke_task(self, mock_fail, clean_dags_dagruns_and_dagbundles, testing_dag_bundle):
         start_date = timezone.utcnow() - timedelta(days=2)
 
         with DAG("test_revoke_task", schedule=None) as dag:
             task = BaseOperator(task_id="task_1", start_date=start_date)
 
         if AIRFLOW_V_3_0_PLUS:
-            dag.sync_to_db()
-            SerializedDagModel.write_dag(dag, bundle_name="testing")
+            sync_dag_to_db(dag)
             dag_version = DagVersion.get_latest_version(task.dag.dag_id)
             ti = TaskInstance(task=task, run_id=None, dag_version_id=dag_version.id)
         else:
